@@ -1,10 +1,9 @@
 ;; test-harness.el --- Run Emacs Lisp test suites.
 
-;;; Copyright (C) 1998, 2002, 2003 Free Software Foundation, Inc.
+;;; Copyright (C) 1998 Free Software Foundation, Inc.
 ;;; Copyright (C) 2002 Ben Wing.
 
 ;; Author: Martin Buchholz
-;; Maintainer: Stephen J. Turnbull <stephen@xemacs.org>
 ;; Keywords: testing
 
 ;; This file is part of XEmacs.
@@ -45,21 +44,10 @@
 
 (require 'bytecomp)
 
-(defvar test-harness-test-compiled nil
-  "Non-nil means the test code was compiled before execution.")
-
 (defvar test-harness-verbose
   (and (not noninteractive) (> (device-baud-rate) search-slow-speed))
   "*Non-nil means print messages describing progress of emacs-tester.")
 
-(defvar test-harness-file-results-alist nil
-  "Each element is a list (FILE SUCCESSES TESTS).
-The order is the reverse of the order in which tests are run.
-
-FILE is a string naming the test file.
-SUCCESSES is a non-negative integer, the number of successes.
-TESTS is a non-negative integer, the number of tests run.")
-
 (defvar test-harness-risk-infloops nil
   "*Non-nil to run tests that may loop infinitely in buggy implementations.")
 
@@ -68,18 +56,6 @@ TESTS is a non-negative integer, the number of tests run.")
 (defvar emacs-lisp-file-regexp (purecopy "\\.el\\'")
   "*Regexp which matches Emacs Lisp source files.")
 
-(defconst test-harness-file-summary-template
-  (format "%%-%ds %%%dd of %%%dd tests successful (%%3d%%%%)."
-	  (length "byte-compiler-tests.el:") ; use the longest file name
-	  5
-	  5)
-  "Format for summary lines printed after each file is run.")
-
-(defconst test-harness-null-summary-template
-  (format "%%-%ds             No tests run."
-	  (length "byte-compiler-tests.el:")) ; use the longest file name
-  "Format for \"No tests\" lines printed after a file is run.")
-
 ;;;###autoload
 (defun test-emacs-test-file (filename)
   "Test a file of Lisp code named FILENAME.
@@ -134,8 +110,7 @@ The output file's name is made by appending `c' to the end of FILENAME."
 	  (setq body (cons (read buffer) body)))
       (end-of-file nil)
       (error
-       (princ (format "Unexpected error %S reading forms from buffer\n"
-		      error-info))))
+       (princ (format "Unexpected error %S reading forms from buffer\n" error-info))))
     `(lambda ()
        (defvar passes)
        (defvar assertion-failures)
@@ -320,8 +295,7 @@ BODY is a sequence of expressions and may contain several tests."
 	 (message "Test suite execution aborted." error-info)
 	 ))
       (princ "\nTesting Compiled Lisp\n\n")
-      (let (code
-	    (test-harness-test-compiled t))
+      (let (code)
 	(condition-case error-info
 	    (setq code
 		  ;; our lisp code is often intentionally dubious,
@@ -355,11 +329,9 @@ BODY is a sequence of expressions and may contain several tests."
 	     (basename (file-name-nondirectory filename))
 	     (summary-msg
 	      (if (> total 0)
-		  (format test-harness-file-summary-template
-			  (concat basename ":")
-			  passes total (/ (* 100 passes) total))
-		(format test-harness-null-summary-template
-			(concat basename ":"))))
+		  (format "%s: %d of %d tests successful (%d%%)."
+			  basename passes total (/ (* 100 passes) total))
+		(format "%s: No tests run" basename)))
 	     (reasons ""))
 	(maphash (lambda (key value)
 		   (setq reasons
@@ -372,9 +344,6 @@ BODY is a sequence of expressions and may contain several tests."
     Probably XEmacs cannot find your installed packages.  Set EMACSPACKAGEPATH
     to the package hierarchy root or configure with --package-path to enable
     the skipped tests.")))
-	(setq test-harness-file-results-alist
-	      (cons (list filename passes total)
-		    test-harness-file-results-alist))
 	(message "%s" summary-msg))
       (when unexpected-test-suite-failure
 	(message "Test suite execution failed unexpectedly."))
@@ -386,8 +355,7 @@ BODY is a sequence of expressions and may contain several tests."
       (fmakunbound 'Int-to-Marker)
       (and noninteractive
 	   (message "%s" (buffer-substring-no-properties
-			  nil nil "*Test-Log*")))
-      )))
+			  nil nil "*Test-Log*"))))))
 
 (defvar test-harness-results-point-max nil)
 (defmacro displaying-emacs-test-results (&rest body)
@@ -466,45 +434,7 @@ For example, invoke \"xemacs -batch -f batch-test-emacs tests/*.el\""
 		  (setq error t))))
 	(or (batch-test-emacs-1 file)
 	    (setq error t))))
-    (let ((namelen 0)
-	  (succlen 0)
-	  (testlen 0)
-	  (results test-harness-file-results-alist))
-      ;; compute maximum lengths of variable components of report
-      ;; probably should just use (length "byte-compiler-tests.el")
-      ;; and 5-place sizes -- this will also work for the file-by-file
-      ;; printing when Adrian's kludge gets reverted
-      (flet ((print-width (i)
-	       (let ((x 10) (y 1))
-		 (while (>= i x)
-		   (setq x (* 10 x) y (1+ y)))
-		 y)))
-	(while results
-	  (let* ((head (car results))
-		 (nn (length (file-name-nondirectory (first head))))
-		 (ss (print-width (second head)))
-		 (tt (print-width (third head))))
-	    (when (> nn namelen) (setq namelen nn))
-	    (when (> ss succlen) (setq succlen ss))
-	    (when (> tt testlen) (setq testlen tt)))
-	  (setq results (cdr results))))
-      ;; create format and print
-      (let ((results (reverse test-harness-file-results-alist)))
-	(while results
-	  (let* ((head (car results))
-		 (basename (file-name-nondirectory (first head)))
-		 (nsucc (second head))
-		 (ntest (third head)))
-	    (if (> ntest 0)
-		(message test-harness-file-summary-template
-			 (concat basename ":")
-			 nsucc
-			 ntest
-			 (/ (* 100 nsucc) ntest))
-	      (message test-harness-null-summary-template
-		       (concat basename ":")))
-	    (setq results (cdr results))))))
-    (message "\nDone")
+    (message "Done")
     (kill-emacs (if error 1 0))))
 
 (provide 'test-harness)
