@@ -85,7 +85,7 @@ includedir=${prefix}/include
 statedir=/var
 libdir=${prefix}/lib
 datadir=${prefix}/share
-infodir=${datadir}/xemacs-${VER}/info
+infodir=${datadir}/xemacs-21.5-b16/info
 mandir=${datadir}/man/man1
 sharedstatedir=${prefix}/com
 localstatedir=/var
@@ -127,26 +127,16 @@ conf() {
     --mandir=${mandir}                                 \
     --package-path=${prefix}/local/share/xemacs/site-packages:${datadir}/xemacs/site-packages:${datadir}/xemacs/xemacs-packages:${datadir}/xemacs/mule-packages \
     --with-mule                                        \
-    --with_file_coding=yes                             \
-    --with_msw=yes                                     \
+    --with_msw=no                                      \
     --with-modules=no                                  \
     --with-dialogs=motif                               \
     --with-widgets=motif                               \
+    --with-dragndrop=no                                \
   2>&1                                                 \
   | tee ${configurelogfile} )
 }
 build() {
-  (cd ${objdir} && \
-  CFLAGS="${MY_CFLAGS}" make        \
-    prefix=${instdir}${prefix}      \
-    datadir=${instdir}${datadir}    \
-    statedir=${instdir}${statedir}  \
-    libdir=${instdir}${libdir}      \
-    infodir=${instdir}${infodir}    \
-    mandir=${instdir}${mandir}      \
-  2>&1 | tee ${makelogfile}    && \
-  rm ./src/xemacs.* ./src/dump-id.* \
-     ./src/update-elc.stamp      && \
+  (cd ${objdir}                  && \
   CFLAGS="${MY_CFLAGS}" make        \
     prefix=${instdir}${prefix}      \
     datadir=${instdir}${datadir}    \
@@ -189,7 +179,7 @@ install() {
   templist=""; \
   for f in ${srcdir}/ANNOUNCE ${srcdir}/CHANGES* ${srcdir}/INSTALL \
            ${srcdir}/KNOWNBUG ${srcdir}/LICENSE ${srcdir}/README* \
-           ${srcdir}/TODO ${srcdir}/COPYING ${srcdir}/ChangeLog \
+           ${srcdir}/TODO* ${srcdir}/COPYING ${srcdir}/ChangeLog \
            ${srcdir}/GETTING.GNU.SOFTWARE ${srcdir}/PROBLEMS \
            ${srcdir}/BUGS ; do \
     if [ -f $f ] ; then \
@@ -274,7 +264,7 @@ spkg() {
   tar cvjf ${src_pkg} * )
 }
 finish() {
-  rm -rf ${srcdir}
+  rm -rf ${srcdir}       && \
   rm ${configurelogfile} > /dev/null 2>&1
   rm ${makelogfile}      > /dev/null 2>&1
   rm ${checklogfile}     > /dev/null 2>&1
